@@ -56,6 +56,11 @@ def page_not_found(error):
 
 # Static file redirection
 @app.route("/favicon.ico")
+def favicon():
+	return flask.redirect(flask.url_for("static", filename="img/favicon.ico"))
+
+
+# Serve robots and sitemap static files
 @app.route('/robots.txt')
 @app.route('/sitemap.xml')
 def static_from_root():
